@@ -105,7 +105,7 @@ void PresetsModel::reload()
         // TODO config
         QVariantMap config;
 
-        KConfigGroup configGroup(df.group("Config"));
+        KConfigGroup configGroup(KSharedConfig::openConfig(p.filePath("config", QStringLiteral("faceproperties"))), QStringLiteral("Config"));
 
         const QStringList keys = configGroup.keyList();
         for (const QString &key : keys) {
@@ -395,6 +395,10 @@ void SensorFaceController::setFaceId(const QString &face)
         d->compactRepresentation->deleteLater();
         d->fullRepresentation.clear();
     }
+    if (d->faceConfigUi) {
+        d->faceConfigUi->deleteLater();
+        d->faceConfigUi.clear();
+    }
 
     d->faceId = face;
 
@@ -418,7 +422,6 @@ void SensorFaceController::setFaceId(const QString &face)
     d->contextObj = new KLocalizedContext(d->engine);
     d->contextObj->setTranslationDomain(QLatin1String("ksysguard_face_") + face);
 
-    //TODO: should be in a different config file rather than metadata
     d->faceProperties = KConfigGroup(KSharedConfig::openConfig(d->facePackage.filePath("FaceProperties")), QStringLiteral("Config"));
 
     const QString xmlPath = d->facePackage.filePath("mainconfigxml");
@@ -480,10 +483,20 @@ QQuickItem *SensorFaceController::faceConfigUi()
         return d->faceConfigUi;
     }
 
+    const QString filePath = d->facePackage.filePath("ui", QStringLiteral("Config.qml"));
+
+    if (filePath.isEmpty()) {
+        return nullptr;
+    }
+
     d->faceConfigUi = d->createConfigUi(QStringLiteral(":/FaceDetailsConfig.qml"),
     {{QStringLiteral("controller"), QVariant::fromValue(this)},
-         {QStringLiteral("source"), d->facePackage.filePath("ui", QStringLiteral("Config.qml"))}});
+         {QStringLiteral("source"), filePath}});
 
+    if (d->faceConfigUi && !d->faceConfigUi->property("item").value<QQuickItem *>()) {
+        d->faceConfigUi->deleteLater();
+        d->faceConfigUi.clear();
+    }
     return d->faceConfigUi;
 }
 
@@ -628,7 +641,7 @@ void SensorFaceController::loadPreset(const QString &preset)
 
 void SensorFaceController::savePreset()
 {
-    QString pluginName = QStringLiteral("org.kde.plasma.systemmonitor.") + title().simplified().replace(QLatin1Char(' '), QChar()).toLower();
+    QString pluginName = QStringLiteral("org.kde.plasma.systemmonitor.") + title().simplified().replace(QLatin1Char(' '), QStringLiteral("")).toLower();
     int suffix = 0;
 
     auto presetPackage = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Applet"));
